@@ -103,7 +103,8 @@ protected:
 
     KDevelop::DeclarationPointer findDeclarationImport(DeclarationType declarationType, IdentifierAst* node);
     KDevelop::DeclarationPointer findDeclarationImport(DeclarationType declarationType, VariableIdentifierAst* node);
-    KDevelop::DeclarationPointer findDeclarationImport(DeclarationType declarationType, const KDevelop::QualifiedIdentifier &identifier, AstNode* node);
+    KDevelop::DeclarationPointer findDeclarationImport(DeclarationType declarationType,
+                                                       const KDevelop::QualifiedIdentifier &identifier);
 
     /// internal functions file should not be checked for errors and can get some optimizations
     bool m_isInternalFunctions;
